@@ -1,10 +1,9 @@
-# vim: set expandtab ts=5 sw=4 filetype=python:
+# vim: set expandtab ts=4 sw=4 filetype=python:
 
 import abc
 import contextlib
 import datetime
 import functools
-import importlib
 import json
 import logging
 import logging.config
@@ -65,7 +64,8 @@ class ConfigWrapper(object):
     #
     configmodule = None
 
-    # Later, you can set up a particular instance as the default instance.
+    # Later, you can set up a particular instance as the default
+    # instance, by using the set_as_default instance method.
     default_instance = None
 
     # Keep a reference of the instances made from each yaml file.
@@ -74,18 +74,11 @@ class ConfigWrapper(object):
     # Just an alias.
     already_instantiated = instances
 
-    # Allow all instances to share a connection to the postgresql database.
+    # Keep these things at the class level, so that all instances share
+    # them.
     postgresql_connection = None
-
-    # Allow all instances to share a jinja2 environment.
     jinja2_environment = None
-
-    # Allow all instances to share a connection to the cloud files
-    cloudfile_connection = None
-
-    # Allow instances to share an SMTP connection.
     smtp_connection = None
-
     pyrax_connection = None
 
     def __init__(self, config_dictionary):
@@ -128,6 +121,12 @@ class ConfigWrapper(object):
 
             return self
 
+    @property
+    def should_register_composite_types(self):
+
+          return self.config_dictionary['postgresql'].get(
+               'should_register_composite_types', False)
+
     def get_postgresql_connection(self, register_composite_types=True):
 
         if not self.postgresql_connection:
@@ -140,32 +139,6 @@ class ConfigWrapper(object):
     # Short aliases are fun too.
     get_pgconn = get_postgresql_connection
 
-    def get_cloudfile_connection(self):
-
-        1/0
-
-        "DO NOT USE THIS!  ALWAYS CREATE A NEW CONNECTION!"
-
-        if not self.cloudfile_connection:
-            cloudconn = self.make_new_cloudfile_connection()
-            self.__class__.cloudfile_connection = cloudconn
-
-        return self.cloudfile_connection
-
-    @property
-    def cloudfile_connection_data(self):
-        return dict(
-           username=self.config_dictionary['cloudfiles']['username'],
-           api_key = self.config_dictionary['cloudfiles']['api-key'])
-
-    def make_new_cloudfile_connection(self):
-
-        cloudconn = cloudfiles.Connection(**self.cloudfile_connection_data)
-
-        log.info("Just made cloudfile connection {0}.".format(cloudconn))
-
-        return cloudconn
-
     @contextlib.contextmanager
     def get_autocommitting_postgresql_connection(self):
 
@@ -190,14 +163,16 @@ class ConfigWrapper(object):
             self.postgresql_connection.commit()
 
     @property
-    def postgresql_connection_data(self):
+    def pyrax_username(self):
+        return self.config_dictionary['cloudfiles']['username']
 
-        return dict(
-            port=self.config_dictionary['postgresql']['port'],
-            database=self.config_dictionary['postgresql']['database'],
-            host=self.config_dictionary['postgresql']['host'],
-            user=self.config_dictionary['postgresql']['user'],
-            password=self.config_dictionary['postgresql']['password'])
+    @property
+    def pyrax_api_key(self):
+        return self.config_dictionary['cloudfiles']['api-key'],
+
+    @property
+    def pyrax_region(self):
+        return "ORD"
 
     @property
     def database_host(self):
@@ -219,13 +194,22 @@ class ConfigWrapper(object):
     def database_user(self):
         return self.config_dictionary['postgresql']['user']
 
+    @property
+    def database_password(self):
+        return self.config_dictionary['postgresql']['password']
+
     def make_database_connection(self, register_composite_types=True):
 
         pgconn = psycopg2.connect(
             connection_factory=psycopg2.extras.NamedTupleConnection,
-            **self.postgresql_connection_data)
+            port=self.database_port,
+            database=self.database_name,
+            host=self.database_host,
+            user=self.database_user,
+            password=self.database_password)
 
-        log.info("Just made postgresql connection {0}.".format(pgconn))
+        log.info("Just made postgresql connection {0}.".format(
+            pgconn))
 
         # Keep a reference to this connection on the class, so that
         # other instances can just recycle this connection.
@@ -485,6 +469,7 @@ class ConfigWrapper(object):
         pyrax.set_setting('identity_type',  'rackspace')
 
         pyrax.set_credentials(
+
             self.config_dictionary['cloudfiles']['username'],
             self.config_dictionary['cloudfiles']['api-key'],
             region="ORD")
@@ -505,63 +490,6 @@ class ConfigWrapper(object):
 
         return self.pyrax_connection
 
-    @property
-    def protocol_folder_id(self):
-
-        try:
-            return self.config_dictionary\
-            ['special_folders']['protocol_folder_id']
-
-        except KeyError:
-            raise MissingConfig(
-                "Sorry, couldn't find a protocol folder ID key!")
-
-    @property
-    def table_of_contents_folder_id(self):
-
-        try:
-            return self.config_dictionary\
-            ['special_folders']['table_of_contents_folder_id']
-
-        except KeyError:
-            raise MissingConfig(
-                "Sorry, couldn't find a protocol folder ID key!")
-
-    @property
-    def current_irb_approved_submission_folder_id(self):
-        try:
-            return self.config_dictionary\
-            ['special_folders']['current_irb_approved_submission']
-
-        except KeyError:
-            raise MissingConfig(
-                "Sorry, couldn't find a key for the current "
-                "IRB-approved submission folder ID!")
-
-    @property
-    def annual_irb_approved_submission_folder_id(self):
-
-        try:
-            return self.config_dictionary\
-            ['special_folders']['annual_irb_approved_submission']
-
-        except KeyError:
-            raise MissingConfig(
-                "Sorry, couldn't find a key for the "
-                "Annual IRB-approved submission folder ID!")
-
-    @property
-    def oversight_folder_id(self):
-
-        try:
-            return self.config_dictionary\
-            ['special_folders']['oversight']
-
-        except KeyError:
-            raise MissingConfig(
-                "Sorry, couldn't find a key for the "
-                "oversight folder ID!")
-
 
     def verify_config_file(self):
 
@@ -584,16 +512,18 @@ class ConfigWrapper(object):
         # property to a class-level (not instance level!) array
         # attribute.
 
+        # In fact, that's what should be done.  So, please do it.
+
         important_properties = [
-            'postgresql_connection_data',
-            'cloudfile_connection_data',
+            'database_port',
+            'database_name',
+            'database_host',
+            'database_user',
+            'database_password',
+            'pyrax_username',
+            'pyrax_api_key',
             'smtp_host',
             'web_host',
-            'table_of_contents_folder_id',
-            'protocol_folder_id',
-            'current_irb_approved_submission_folder_id',
-            'annual_irb_approved_submission_folder_id',
-            'oversight_folder_id',
         ]
 
         log.debug('Verifying config file contents:')
